Class: Dev::Template::ApplicationInterface

Inherits:
BaseInterface show all
Includes:
Rake::DSL
Defined in:
lib/firespring_dev_commands/templates/base_interface.rb

Overview

Base interface template customized for applications which require a name to be passed in to the constructor

Instance Method Summary collapse

Methods inherited from BaseInterface

#create_tasks!

Constructor Details

#initialize(name, exclude: []) ⇒ ApplicationInterface

Returns a new instance of ApplicationInterface.



35
36
37
38
# File 'lib/firespring_dev_commands/templates/base_interface.rb', line 35

def initialize(name, exclude: [])
  @name = name
  super(exclude: exclude)
end