Class: Dev::Template::Docker::Php::Application

Inherits:
ApplicationInterface show all
Defined in:
lib/firespring_dev_commands/templates/docker/php/application.rb

Overview

Class for default rake tasks associated with a php project

Instance Attribute Summary collapse

Attributes inherited from ApplicationInterface

#name

Attributes inherited from BaseInterface

#exclude

Instance Method Summary collapse

Methods inherited from BaseInterface

#create_tasks!

Constructor Details

#initialize(application, container_path: nil, local_path: nil, start_container_dependencies_on_test: true, exclude: []) ⇒ Application

Create the templated rake tasks for the php application

Parameters:

  • application (String) —

    The name of the application

  • container_path (String) (defaults to: nil) —

    The path to the application inside of the container

  • local_path (String) (defaults to: nil) —

    The path to the application on your local system

  • start_container_dependencies_on_test (Boolean) (defaults to: true) —

    Whether or not to start up container dependencies when running tests



18
19
20
21
22
23
24
25
26
27
28
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 18

def initialize(
  application,
  container_path: nil,
  local_path: nil,
  start_container_dependencies_on_test: true,
  exclude: []
)
  @php = Dev::Php.new(container_path:, local_path:)
  @start_container_dependencies_on_test = start_container_dependencies_on_test
  super(application, exclude:)
end

Instance Attribute Details

#php ⇒ Object (readonly)

Returns the value of attribute php.



10
11
12
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 10

def php
  @php
end

#start_container_dependencies_on_test ⇒ Object (readonly)

Returns the value of attribute start_container_dependencies_on_test.



10
11
12
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 10

def start_container_dependencies_on_test
  @start_container_dependencies_on_test
end

Instance Method Details

#create_audit_task! ⇒ Object

Create the rake tasks which runs the security audits for the application packages



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 163

def create_audit_task!
  # Have to set a local variable to be accessible inside of the instance_eval block
  application = @name
  php = @php
  exclude = @exclude
  return if exclude.include?(:audit)

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      desc 'Run all security audits'
      task audit: %w(php:audit) do
        # This is just a placeholder to execute the dependencies
      end

      namespace :php do
        desc 'Run Composer Audit on the target application' \
             "\n\tuse MIN_SEVERITY=(info low moderate high critical) to fetch only severity type selected and above (default=high)." \
             "\n\tuse IGNORELIST=(comma delimited list of cwe numbers) removes the entry from the list."
        task audit: %w(init_docker up_no_deps) do
          opts = []
          opts << '-T' if Dev::Common.new.running_codebuild?

          # Retrieve results of the scan.
          data = Dev::Docker::Compose.new(services: application, options: opts, capture: true).exec(*php.audit_command)
          Dev::Php::Audit.new(data).to_report.check
        end

        # namespace :audit do
        #   desc 'Fix the composer vulnerabilities that were found'
        #   task fix: %w(init_docker up_no_deps) do
        #     raise 'not implemented'
        #     # Dev::Docker::Compose.new(services: application).exec(*php.audit_fix_command)
        #   end
        # end
      end
    end
  end
end

#create_install_task! ⇒ Object

Create the rake tasks which runs the install command for the application packages



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 143

def create_install_task!
  # Have to set a local variable to be accessible inside of the instance_eval block
  application = @name
  php = @php
  exclude = @exclude
  return if exclude.include?(:install)

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      namespace :php do
        desc 'Install all composer packages'
        task install: %w(init_docker up_no_deps) do
          Dev::Docker::Compose.new(services: application).exec(*php.install_command)
        end
      end
    end
  end
end

#create_lint_task! ⇒ Object

Create the rake task which runs linting for the application name



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 75

def create_lint_task!
  application = @name
  php = @php
  exclude = @exclude
  return if exclude.include?(:lint)

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      desc 'Run all linting software'
      task lint: %w(php:lint) do
        # This is just a placeholder to execute the dependencies
      end

      namespace :php do
        desc "Run the php linting software against the #{application}'s codebase"
        task lint: %w(init_docker up_no_deps) do
          LOG.debug("Check for php linting errors in the #{application} codebase")

          options = []
          options << '-T' if Dev::Common.new.running_codebuild?
          Dev::Docker::Compose.new(services: application, options:).exec(*php.lint_command)
        end

        namespace :lint do
          desc "Run the php linting software against the #{application}'s codebase and apply all available fixes"
          task fix: %w(init_docker up_no_deps) do
            LOG.debug("Check and fix all php linting errors in the #{application} codebase")

            options = []
            options << '-T' if Dev::Common.new.running_codebuild?
            Dev::Docker::Compose.new(services: application, options:).exec(*php.lint_fix_command)
          end
        end
      end
    end
  end
end

#create_test_task! ⇒ Object

Create the rake task which runs all tests for the application name



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 114

def create_test_task!
  application = @name
  php = @php
  exclude = @exclude
  up_cmd = @start_container_dependencies_on_test ? :up : :up_no_deps
  return if exclude.include?(:test)

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      desc 'Run all tests'
      task test: %w(php:test) do
        # This is just a placeholder to execute the dependencies
      end

      namespace :php do
        desc "Run all php tests against the #{application}'s codebase"
        task test: %W(init_docker #{up_cmd}) do
          LOG.debug("Running all php tests in the #{application} codebase")

          options = []
          options << '-T' if Dev::Common.new.running_codebuild?
          Dev::Docker::Compose.new(services: application, options:).exec(*php.test_command)
        end
      end
    end
  end
end

#create_vendor_download_task! ⇒ Object

Create the rake task which downloads the vendor directory to your local system for the given application name



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 31

def create_vendor_download_task!
  application = @name
  php = @php
  exclude = @exclude
  return if exclude.include?(:'vendor:download')

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      namespace :php do
        namespace :vendor do
          desc "Copy #{application} vendor files from the container to your local system"
          task download: %w(init_docker up_no_deps) do
            container = Dev::Docker::Compose.new.container_by_name(application)
            Dev::Docker.new.copy_from_container(container, "#{php.container_path}/vendor/", "#{php.local_path}/vendor/", required: true)
          end
        end
      end
    end
  end
end

#create_vendor_upload_task! ⇒ Object

Create the rake task which uploads the vendor directory from your local system for the given application name



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/firespring_dev_commands/templates/docker/php/application.rb', line 53

def create_vendor_upload_task!
  application = @name
  php = @php
  exclude = @exclude
  return if exclude.include?(:'vendor:upload')

  DEV_COMMANDS_TOP_LEVEL.instance_eval do
    namespace application do
      namespace :php do
        namespace :vendor do
          desc "Copy #{application} vendor files from your local system to the container"
          task upload: %w(init_docker up_no_deps) do
            container = Dev::Docker::Compose.new.container_by_name(application)
            Dev::Docker.new.copy_to_container(container, "#{php.local_path}/vendor/", "#{php.container_path}/vendor/")
          end
        end
      end
    end
  end
end